@@ -123,6 +123,8 @@ class MenuItem(template.Node):
             
         if url.startswith('url:'):
             url = reverse(url[4:])
+        elif url.startswith('http'):
+            pass
         else:
             url = resolve_path(url, context)
         
@@ -149,6 +151,11 @@ class MenuItem(template.Node):
                 raise template.TemplateSyntaxError("menu_item tag requires 'request' in context")
             return ''
         
+        # If it is an absolute URL, we can shortcut.
+        if url.startswith('http'):
+            self._update_nodelist()
+            return self.nodelist.render(template.context.Context(local))
+        
         request = context['request']
         
         # To find our current url, look in order at these.
@@ -186,6 +193,17 @@ class MenuItem(template.Node):
         if not can_view:
             return ''
         
+        # Special-case: when the menu-item's url is '/' or text is 'home', then we don't mark
+        # it as active unless it's a complete match.
+        if page_url.startswith(local['url']):
+            if (local['url'] != '/' and local['text'].lower() != 'home') or page_url == local['url']:
+                local['classes'] += " active"
+        
+        self._update_nodelist()
+        new_context = template.context.Context(local)
+        return self.nodelist.render(new_context)
+    
+    def _update_nodelist(self):
         # Now import and render the template.
         file_name = self.template_file
         
@@ -199,16 +217,7 @@ class MenuItem(template.Node):
             else:
                 t = get_template(file_name)
             self.nodelist = t.nodelist
-        
-        # Special-case: when the menu-item's url is '/' or text is 'home', then we don't mark
-        # it as active unless it's a complete match.
-        if page_url.startswith(local['url']):
-            if (local['url'] != '/' and local['text'].lower() != 'home') or page_url == local['url']:
-                local['classes'] += " active"
-        
-        new_context = template.context.Context(local)
-        return self.nodelist.render(new_context)
-        
+    
     
 def base_menu_item(template="menu/item.html"):
     """
